@@ -6,7 +6,7 @@
 ;;         Naoya Yamashita <conao3@gmail.com>
 ;; Maintainer: Feng Shu <tumashu@163.com>
 ;; URL: https://github.com/tumashu/ivy-posframe
-;; Version: 0.6.3
+;; Version: 0.6.4
 ;; Keywords: abbrev, convenience, matching, ivy
 ;; Package-Requires: ((emacs "26.0") (posframe "1.0.0") (ivy "0.13.0"))
 
@@ -257,8 +257,8 @@ This variable is useful for `ivy-posframe-read-action' .")
     (or (ignore-errors
           (let ((info (elt exwm-workspace--workareas
                            exwm-workspace-current-index)))
-            (cons (elt info 0)
-                  (elt info 1))))
+            (cons (oref info x)
+                  (oref info y))))
         ;; Need user install xwininfo.
         (ignore-errors
           (posframe-refposhandler-xwininfo frame))
@@ -285,6 +285,7 @@ This variable is useful for `ivy-posframe-read-action' .")
             :override-parameters ivy-posframe-parameters
             :refposhandler ivy-posframe-refposhandler
             :hidehandler #'ivy-posframe-hidehandler
+            :tty-non-selected-cursor t
             (funcall ivy-posframe-size-function))
      (ivy-posframe--add-prompt 'ignore)))
   (with-current-buffer ivy-posframe-buffer
@@ -329,6 +330,9 @@ This variable is useful for `ivy-posframe-read-action' .")
 (defun ivy-posframe-display-at-frame-bottom-left (str)
   (ivy-posframe--display str #'posframe-poshandler-frame-bottom-left-corner))
 
+(defun ivy-posframe-display-at-frame-bottom-center (str)
+  (ivy-posframe--display str #'posframe-poshandler-frame-bottom-center))
+
 (defun ivy-posframe-display-at-frame-bottom-window-center (str)
   (ivy-posframe--display
    str (lambda (info)
@@ -586,7 +590,7 @@ This variable is useful for `ivy-posframe-read-action' .")
 
 (defun ivy-posframe--minibuffer-setup (fn &rest args)
   "Advice function of FN, `ivy--minibuffer-setup' with ARGS."
-  (if (not (display-graphic-p))
+  (if (not (posframe-workable-p))
       (apply fn args)
     (let ((ivy-fixed-height-minibuffer nil))
       (apply fn args))
@@ -610,7 +614,7 @@ This variable is useful for `ivy-posframe-read-action' .")
 (defun ivy-posframe--add-prompt (fn &rest args)
   "Add the ivy prompt to the posframe.  Advice FN with ARGS."
   (apply fn args)
-  (when (and (display-graphic-p)
+  (when (and (posframe-workable-p)
              (not ivy-posframe--ignore-prompt))
     (with-current-buffer (window-buffer (active-minibuffer-window))
       (let ((point (point))
@@ -624,7 +628,7 @@ This variable is useful for `ivy-posframe-read-action' .")
 
 (defun ivy-posframe--display-function-prop (fn &rest args)
   "Around advice of FN with ARGS."
-  (if (not (display-graphic-p))
+  (if (not (posframe-workable-p))
       (apply fn args)
     (let ((ivy-display-functions-props
            (append ivy-display-functions-props
@@ -636,7 +640,7 @@ This variable is useful for `ivy-posframe-read-action' .")
 
 (defun ivy-posframe--height (fn &rest args)
   "Around advide of FN with ARGS."
-  (if (not (display-graphic-p))
+  (if (not (posframe-workable-p))
       (apply fn args)
     (let ((ivy-height-alist
            (append ivy-posframe-height-alist ivy-height-alist)))
@@ -644,7 +648,7 @@ This variable is useful for `ivy-posframe-read-action' .")
 
 (defun ivy-posframe--read (fn &rest args)
   "Around advice of FN with AGS."
-  (if (not (display-graphic-p))
+  (if (not (posframe-workable-p))
       (apply fn args)
     (let ((ivy-display-functions-alist
            (append ivy-posframe-display-functions-alist ivy-display-functions-alist)))
